@@ -63,8 +63,15 @@ class ListApplicationHandler(BaseHandler):
         try:
             offset = int(self.get_argument("offset", "0"))
             limit = int(self.get_argument("limit", "0"))
+            filters = {}
+            name = self.get_argument("name", "")
+            if name:
+                filters["name"] = name
+            app_id = self.get_argument("id", "")
+            if app_id:
+                filters["id"] = app_id
             LOG.debug("ListApplicationHandler offset: %s, limit: %s", offset, limit)
-            r = Applications.instance().list(offset = offset, limit = limit)
+            r = Applications.instance().list(offset = offset, limit = limit, filters = filters)
             result["apps"] = r["apps"]
             result["total"] = r["total"]
             result["offset"] = offset
