@@ -267,9 +267,27 @@ class ListTaskHandler(BaseHandler):
         try:
             offset = int(self.get_argument("offset", "0"))
             limit = int(self.get_argument("limit", "0"))
+            filters = {}
+            task_id = self.get_argument("task_id", "")
+            if task_id:
+                filters["task_id"] = task_id
+            app_id = self.get_argument("app_id", "")
+            if app_id:
+                filters["app_id"] = app_id
+            work_id = self.get_argument("work_id", "")
+            if work_id:
+                filters["work_id"] = work_id
+            name = self.get_argument("name", "")
+            if name:
+                filters["name"] = name
             stage = self.get_argument("stage", "")
-            LOG.debug("ListTaskHandler offset: %s, limit: %s, stage: %s", offset, limit, stage)
-            r = Tasks.instance().list(offset = offset, limit = limit, stage = stage)
+            if stage:
+                filters["stage"] = stage
+            status = self.get_argument("status", "")
+            if status:
+                filters["status"] = status
+            LOG.debug("ListTaskHandler offset: %s, limit: %s, filters: %s", offset, limit, filters)
+            r = Tasks.instance().list(offset = offset, limit = limit, filters = filters)
             result["tasks"] = r["tasks"]
             result["total"] = r["total"]
             result["offset"] = offset
