@@ -18,7 +18,7 @@ BUF_SIZE = 65536
 
 class Servers(object):
     HTTP_SERVER = None
-    DB_SERVERS = []
+    SERVERS = []
     TORNADO_INSTANCE = None
 
 
@@ -27,9 +27,12 @@ async def shutdown():
     if Servers.HTTP_SERVER:
         Servers.HTTP_SERVER.stop()
         LOG.info("Stop http server!")
-    for db_server in Servers.DB_SERVERS:
-        db_server.close()
-        LOG.info("Stop db server!")
+    for s in Servers.SERVERS:
+        s.close()
+        if hasattr(s, "name"):
+            LOG.info("Stop %s server!", s.name)
+        else:
+            LOG.info("Stop nameless server!")
     await gen.sleep(1)
     LOG.info("Will shutdown ...")
     ioloop.IOLoop.current().stop()
@@ -51,6 +54,12 @@ class Errors(object):
         "TaskAlreadyFinished": {"name": "TaskAlreadyFinished", "message": "task already finished"},
         "TaskAlreadySuccess": {"name": "TaskAlreadySuccess", "message": "task already success"},
         "TaskStillRunning": {"name": "TaskStillRunning", "message": "task still running"},
+        "WorkNotExists": {"name": "WorkNotExists", "message": "work not exists"},
+        "WorkAlreadyFinished": {"name": "WorkAlreadyFinished", "message": "work already finished"},
+        "WorkAlreadySuccess": {"name": "WorkAlreadySuccess", "message": "work already success"},
+        "WorkStillRunning": {"name": "WorkStillRunning", "message": "work still running"},
+        "WorkflowDisabled": {"name": "WorkflowDisabled", "message": "workflow disabled"},
+        "WorkflowNotExists": {"name": "WorkflowNotExists", "message": "workflow not exists"},
         "NodeNotExists": {"name": "NodeNotExists", "message": "node not exists"},
         "ActionNotFinished": {"name": "ActionNotFinished", "message": "action not finished"},
         "ActionNoNodeId": {"name": "ActionNoNodeId", "message": "action no node id"},
@@ -85,6 +94,7 @@ class Status(object):
     kill = "kill"
     cancel = "cancel"
     terminate = "terminate"
+    error = "error"
 
 
 class Signal(object):
