@@ -58,7 +58,7 @@ class Scheduler(object):
         self.periodic_execute.start()
         self.periodic_crontab = tornado.ioloop.PeriodicCallback(
             self.crontab_service, 
-            60 * 1000 # 1 min
+            30 * 1000 # 30 seconds
         )
         self.periodic_crontab.start()
         self.periodic_work = tornado.ioloop.PeriodicCallback(
@@ -261,6 +261,7 @@ class Scheduler(object):
             executable_action = self.select_executable_action()
             if executable_action is None and len(self.running_actions) < Connection.total_action_slots:
                 result = True
+            LOG.debug("can_load_more_task, executable_action: %s, running_actions: %s, total_action_slots: %s", executable_action, len(self.running_actions), Connection.total_action_slots)
         except Exception as e:
             LOG.exception(e)
         return result
@@ -661,9 +662,12 @@ class Scheduler(object):
                 action = self.select_executable_action()
                 LOG.info("seleted action: %s", action)
                 if action:
-                    if "input_data" in action and "action_info" in action["input_data"]:
-                        action["input_data"]["action_info"]["http_host"] = http_host
-                        action["input_data"]["action_info"]["http_port"] = http_port
+                    if "input_data" in action:
+                        action["input_data"]["ldfs_host"] = CONFIG["ldfs_http_host"]
+                        action["input_data"]["ldfs_port"] = CONFIG["ldfs_http_port"]
+                        if "action_info" in action["input_data"]:
+                            action["input_data"]["action_info"]["http_host"] = http_host
+                            action["input_data"]["action_info"]["http_port"] = http_port
                     url = "http://%s:%s/action/run" % (http_host, http_port)
                     request = HTTPRequest(url = url, method = "POST", body = json.dumps(action))
                     r = yield self.async_client.fetch(request)
@@ -711,16 +715,17 @@ class Scheduler(object):
                             fp.close()
                             finish_condition = []
                             task_info["output_action"] = app_config["output_action"]
-                            action_info = {"task_create_at": task_info["create_at"], "task_name": task_info["task_name"]}
                             if task_info["stage"] == Stage.pending: # load pending task
                                 for action in app_config["actions"]:
                                     action["task_id"] = task_id
                                     action["app_id"] = app_id
                                     action["app_sha1"] = app_info["sha1"]
                                     action["task_create_at"] = task_info["create_at"]
-                                    action["input_data"] = task_info["input_data"]
-                                    action_info["action_name"] = action["name"]
-                                    action["input_data"]["action_info"] = action_info
+                                    action["input_data"] = deepcopy(task_info["input_data"])
+                                    action["input_data"]["action_info"] = {}
+                                    action["input_data"]["action_info"]["task_create_at"] = task_info["create_at"]
+                                    action["input_data"]["action_info"]["task_name"] = task_info["task_name"]
+                                    action["input_data"]["action_info"]["action_name"] = action["name"]
                                     finish_condition.append(action["name"])
                                     self.pending_actions.append(action)
                                 event_actions = {}
@@ -750,9 +755,11 @@ class Scheduler(object):
                                     action["app_id"] = app_id
                                     action["app_sha1"] = app_info["sha1"]
                                     action["task_create_at"] = task_info["create_at"]
-                                    action["input_data"] = task_info["input_data"]
-                                    action_info["action_name"] = action["name"]
-                                    action["input_data"]["action_info"] = action_info
+                                    action["input_data"] = deepcopy(task_info["input_data"])
+                                    action["input_data"]["action_info"] = {}
+                                    action["input_data"]["action_info"]["task_create_at"] = task_info["create_at"]
+                                    action["input_data"]["action_info"]["task_name"] = task_info["task_name"]
+                                    action["input_data"]["action_info"]["action_name"] = action["name"]
                                     finish_condition.append(action["name"])
                                     actions_tmp[action["name"]] = action
                                 event_actions = {}
@@ -785,8 +792,10 @@ class Scheduler(object):
                                         action["app_id"] = app_id
                                         action["app_sha1"] = app_info["sha1"]
                                         action["task_create_at"] = task_info["create_at"]
-                                        action_info["action_name"] = action["name"]
-                                        action["input_data"]["action_info"] = action_info
+                                        action["input_data"]["action_info"] = {}
+                                        action["input_data"]["action_info"]["task_create_at"] = task_info["create_at"]
+                                        action["input_data"]["action_info"]["task_name"] = task_info["task_name"]
+                                        action["input_data"]["action_info"]["action_name"] = action["name"]
                                         if "signal" in action:
                                             del action["signal"]
                                         actions_tmp[action["name"]] = action
