@@ -5,6 +5,7 @@ function taskInit (manager_host) {
     var scrollBarSize = getBrowserScrollSize();
     var $btn_refresh = $("#btn_refresh");
     var $btn_create = $("#btn_create");
+    var $btn_search = $("#btn_search");
     var $btn_task_create = $('#btn_task_create');
     var $btn_task_delete = $('#btn_task_delete');
     var $btn_task_rerun = $('#btn_task_rerun');
@@ -13,12 +14,15 @@ function taskInit (manager_host) {
     var $btn_task_download = $('#btn_task_download');
     var task_info = {};
     var current_task_id = "";
+    var filter_type = "";
+    var filter_value = "";
     var current_page = 1;
     var current_page_size = 50;
 
     getTaskList();
     $btn_refresh.bind('click', refreshPage);
     $btn_create.bind('click', showCreate);
+    $btn_search.bind('click', search);
     $("#task_create_modal").on("hidden.bs.modal", resetModal);
     $btn_task_create.bind('click', createTask);
     $btn_task_delete.bind('click', deleteTask);
@@ -62,9 +66,13 @@ function taskInit (manager_host) {
     }
 
     function getTaskList(task_id) {
+        var url = "http://" + manager_host + "/task/list?offset=" + ((current_page - 1) * current_page_size) + "&limit=" + current_page_size;
+        if (filter_type) {
+            url += "&" + filter_type + "=" + filter_value;
+        }
         $.ajax({
             dataType: "json",
-            url: "http://" + manager_host + "/task/list?offset=" + ((current_page - 1) * current_page_size) + "&limit=" + current_page_size,
+            url: url,
             success: function(data) {
                 if (data.result != "ok") {
                     showWarningToast("operation failed", data.message);
@@ -75,6 +83,7 @@ function taskInit (manager_host) {
                 $table_header_tr.append(getHeaderTR('task_id', 'task id', 'task id'));
                 $table_header_tr.append(getHeaderTR('task_name', 'name', 'name'));
                 $table_header_tr.append(getHeaderTR('application_id', 'application id', 'application id'));
+                $table_header_tr.append(getHeaderTR('work_id', 'work id', 'work id'));
                 $table_header_tr.append(getHeaderTR('create_at', 'create at', 'create at'));
                 $table_header_tr.append(getHeaderTR('start_at', 'start at', 'start at'));
                 $table_header_tr.append(getHeaderTR('end_at', 'end at', 'end at'));
@@ -86,6 +95,7 @@ function taskInit (manager_host) {
                     "task_id",
                     "task_name",
                     "application_id",
+                    "work_id",
                     "create_at",
                     "start_at",
                     "end_at",
@@ -110,7 +120,7 @@ function taskInit (manager_host) {
                             tr += '<button id="' + value["task_id"] + '" type="button" class="btn btn-secondary btn-sm btn-operation btn-delete" onclick="this.blur();"><span class="oi oi-circle-x" title="delete" aria-hidden="true"></span></button>';
                             tr += '<button id="' + value["task_id"] + '" type="button" class="btn btn-secondary btn-sm btn-operation btn-detail" onclick="this.blur();"><span class="oi oi-spreadsheet" title="detail" aria-hidden="true"></span></button>';
                             tr += '</div></div></td>';
-                        } else if (col == 'task_id' || col == 'application_id') {
+                        } else if (col == 'task_id' || col == 'application_id' || col == 'work_id') {
                             tr += '<td id="' + col + '"><div class="outer"><div class="inner"><span class="span-pre">' + value[col] + '</span></div></div></td>';
                         } else if (col == 'task_name') {
                             tr += '<td id="' + col + '" title="' + value[col] + '"><div class="outer"><div class="inner">&nbsp;' + value[col] + '</div></div></td>';
@@ -175,6 +185,13 @@ function taskInit (manager_host) {
         getTaskList();
     }
 
+    function search() {
+        filter_type = $('#filter').val();
+        filter_value = $('input#filter_input').val();
+        current_page = 1;
+        getTaskList();
+    }
+
     function showTaskRerun() {
         current_task_id = $(this).attr("id");
         $('#task_rerun_modal').modal('show');
@@ -427,6 +444,11 @@ function taskInit (manager_host) {
             $('td#application_id').css("width", "10%");
             percent -= 10.0;
         }
+        if (is_in('work_id', keys)) {
+            $('th#work_id').css("width", "10%");
+            $('td#work_id').css("width", "10%");
+            percent -= 10.0;
+        }
         if (is_in('stage', keys)) {
             $('th#stage').css("width", "5%");
             $('td#stage').css("width", "5%");
